Enum Request
#[non_exhaustive]pub enum Request {
SetTimestamp {
tv_sec_hi: u32,
tv_sec_lo: u32,
tv_nsec: u32,
},
Destroy,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SetTimestamp
Specify time the following commit takes effect
Provide a timing constraint for a surface content update.
A set_timestamp request may be made before a wl_surface.commit to tell the compositor that the content is intended to be presented as closely as possible to, but not before, the specified time. The time is in the domain of the compositor’s presentation clock.
An invalid_timestamp error will be generated for invalid tv_nsec.
If a timestamp already exists on the surface, a timestamp_exists error is generated.
Requesting set_timestamp after the commit_timer object’s surface is destroyed will generate a “surface_destroyed” error.
Fields
Destroy
Destroy the timer
Informs the server that the client will no longer be using this protocol object.
Existing timing constraints are not affected by the destruction.
This is a destructor, once received this object cannot be used any longer.
Implementations